kibitzr.transformer package
===========================

Submodules
----------

kibitzr.transformer.factory module
----------------------------------

.. automodule:: kibitzr.transformer.factory
    :members:
    :undoc-members:
    :show-inheritance:

kibitzr.transformer.html module
-------------------------------

.. automodule:: kibitzr.transformer.html
    :members:
    :undoc-members:
    :show-inheritance:

kibitzr.transformer.jinja_transform module
------------------------------------------

.. automodule:: kibitzr.transformer.jinja_transform
    :members:
    :undoc-members:
    :show-inheritance:

kibitzr.transformer.json_transforms module
------------------------------------------

.. automodule:: kibitzr.transformer.json_transforms
    :members:
    :undoc-members:
    :show-inheritance:

kibitzr.transformer.plain_text module
-------------------------------------

.. automodule:: kibitzr.transformer.plain_text
    :members:
    :undoc-members:
    :show-inheritance:

kibitzr.transformer.utils module
--------------------------------

.. automodule:: kibitzr.transformer.utils
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: kibitzr.transformer
    :members:
    :undoc-members:
    :show-inheritance:
